pre, code {
    color: #eef0f9;
    background-color: #17191e;
}

.hl-keyword {
    color: #54b9ff;
}

.hl-property {
    color: #00daef;
}

.hl-attribute {
    font-style: italic;
}

.hl-type {
    color: #acafff;
}

.hl-generic {
    color: #9d3af6;
}

.hl-value {
    color: #ffd493;
}

.hl-literal {
    color: #ffd493;
}

.hl-number {
    color: #ffd493;
}

.hl-variable {
    color: #4bf3c8;
}

.hl-comment {
    color: #888888;
}

.hl-blur {
    filter: blur(2px);
}

.hl-strong {
    font-weight: bold;
}

.hl-em {
    font-style: italic;
}

.hl-addition {
    display: inline-block;
    min-width: 100%;
    background-color: #00FF0022;
}

.hl-deletion {
    display: inline-block;
    min-width: 100%;
    background-color: #FF000011;
}

.hl-gutter {
    display: inline-block;
    font-size: 0.9em;
    color: #555;
    padding: 0 1ch;
    margin-right: 1ch;
    user-select: none;
}

.hl-gutter-addition {
    background-color: #34A853;
    color: #fff;
}

.hl-gutter-deletion {
    background-color: #EA4334;
    color: #fff;
}
