.hl-moderate-sentence {
    background-color: #fef9c3;
}

.hl-complex-sentence {
    background-color: #fee2e2;
}

.hl-adverb-phrase {
    background-color: #e0f2fe;
}

.hl-passive-phrase {
    background-color: #dcfce7;
}

.hl-complex-phrase {
    background-color: #f3e8ff;
}

.hl-qualified-phrase {
    background-color: #f1f5f9;
}
